@@ -275,6 +275,8 @@ def gen_class_h(bdir, data):
 			if c.cname == 'Closure': op = '\tknh_fmethod finvoke_1;\n\tknh_fmethod fcallcc_2;\n'
 			if c.cname == 'Token':    op = '\tknh_fileid_t fileid;\n\tknh_ushort_t line;\n\tknh_flag_t flag;\n\tknh_token_t  tt;\n'
 			if c.cname == 'Stmt':     op = '\tknh_fileid_t fileid;\n\tknh_ushort_t line;\n\tknh_flag_t flag;\n\tknh_stmt_t  stt;\n'
+			if c.cname == 'Asm':    op = '\tknh_fileid_t fileid;\n\tknh_ushort_t line;\n'
+			if c.cname == 'KLRCode':     op = '\tknh_fileid_t fileid;\n\tknh_ushort_t line;\n'
 			#if c.cname == 'Asm': op = '\tknh_fileid_t fileid;\n\tknh_ushort_t line;\n\tknh_flag_t flag;\n\tknh_ushort_t dummy;\n'
 			f.write('''
 typedef struct knh_%s_t {
