@@ -239,7 +239,7 @@ typedef struct knh_FArray_t {
 /* @class Iterator Object knh_Iterator_struct @Param1 */
 
 #ifdef _MSC_VER
-typedef void   (KNH_CC_FASTCALL *knh_fitrnext)(Ctx *, knh_sfp_t *, int n);
+typedef int   (KNH_CC_FASTCALL *knh_fitrnext)(Ctx *, knh_sfp_t *, int n);
 #else
 typedef ITRNEXT (*knh_fitrnext)(Ctx *, knh_sfp_t *, int n);
 #endif
@@ -626,14 +626,14 @@ typedef struct knh_StringUnit {
 
 /* ------------------------------------------------------------------------ */
 /* @class InputStream Object knh_InputStream_struct */
-/* @flag InputStream.STDIN IN:1 (%s)->h.flag 'is:set:*:*' */
+/* @flag InputStream.FILE IN:1 (%s)->h.flag 'is:set:*:*' */
 
 typedef struct knh_InputStream {
 	union {
 		knh_io_t fd;
 		FILE *fp;
 	};
-	knh_iodrv_t driver;
+	knh_iodrv_t *driver;
 	union {
 		struct knh_Bytes_t *ba;
 		struct knh_String_t *str;
@@ -657,9 +657,9 @@ typedef struct knh_InputStream {
 /* @flag OutputStream.AutoFlush OUT:2 (%s)->h.flag 'is:set:is:set' */
 /* @flag OutputStream.StoringBuffer OUT:3 (%s)->h.flag 'is:set:is:set' */
 
-typedef struct knh_OutputStream {
+typedef struct {
 	knh_io_t fd;
-	knh_iodrv_t driver;
+	knh_iodrv_t *driver;
 	knh_Bytes_t* ba;
 	knh_String_t *enc;
 	struct knh_BytesConv_t* bconv;
@@ -672,6 +672,17 @@ typedef struct knh_OutputStream {
 	knh_flag_t flag;  /*unused */
 } knh_OutputStream_struct;
 
+/* ------------------------------------------------------------------------ */
+/* @class Socket Object knh_Socket_struct */
+
+typedef struct {
+	knh_intptr_t sd;
+	knh_intptr_t port;
+	struct knh_String_t *urn;
+	struct knh_InputStream_t  *in;
+	struct knh_OutputStream_t *out;
+} knh_Socket_struct;
+
 /* ======================================================================== */
 /* @class Connection Object knh_Connection_struct */
 /* @class ResultSet Object knh_ResultSet_struct */
@@ -753,7 +764,7 @@ typedef struct knh_ExceptionHandler {
 } knh_ExceptionHandler_struct;
 
 /* ------------------------------------------------------------------------ */
-/* @class Script Object knh_Script_t */
+/* @class Script Object knh_Script_t @Private */
 
 #define KNH_SCRIPT_FIELDSIZE   128
 
@@ -765,22 +776,6 @@ typedef struct knh_Script_t {
 /* ------------------------------------------------------------------------ */
 /* @class NameSpace Object knh_NameSpace_struct @Private */
 
-//typedef int (*f_pkginit)(Ctx *ctx);
-//typedef void (*f_pkgtraverse)(Ctx *ctx, knh_ftraverse ftr);
-//
-//typedef struct knh_pkgmeta_t {
-//	const int buildid;
-//	const char *name;  /* "unix" */
-//	const char *version; /* "version" */
-//	const char *desc;
-//	const char *url;
-//	f_pkginit finit;
-//	f_pkgtraverse ftraverse;
-//	const char *script;
-//} knh_pkgmeta_t;
-//
-//typedef knh_pkgmeta_t* (*f_pkgload)(Ctx *ctx);
-
 typedef struct knh_NameSpace {
 	knh_String_t*           nsname;
 	struct knh_Script_t*    script;
