@@ -42,8 +42,12 @@ extern "C" {
 /* ../src/api/arrayapi.c */
 void knh_Array_clear(Ctx *ctx, Array *o);
 void knh_Array__k(Ctx *ctx, Array *o, OutputStream *w, String *m);
+void knh_IArray__k(Ctx *ctx, IArray *o, OutputStream *w, String *m);
+void knh_FArray__k(Ctx *ctx, FArray *o, OutputStream *w, String *m);
 MAPPER knh_Array_Iterator(Ctx *ctx, knh_sfp_t *sfp);
 MAPPER knh_Iterator_Array(Ctx *ctx, knh_sfp_t *sfp);
+MAPPER knh_IArray_Iterator(Ctx *ctx, knh_sfp_t *sfp);
+MAPPER knh_FArray_Iterator(Ctx *ctx, knh_sfp_t *sfp);
 Mapper *knh_tMapper_newIteratorArray(Ctx *ctx, knh_class_t icid, knh_class_t acid);
 Mapper *knh_tMapper_newArrayIterator(Ctx *ctx, knh_class_t acid, knh_class_t icid);
 void knh_array_dfree(Ctx *ctx, void *ptr, size_t capacity, size_t usize);
@@ -60,6 +64,11 @@ void knh_Method__k(Ctx *ctx, Method *o, OutputStream *w, String *m);
 void knh_Method__dump(Ctx *ctx, Method *o, OutputStream *w, String *m);
 /* ../src/api/streamapi.c */
 void knh_OutputStream__k(Ctx *ctx, OutputStream *o, OutputStream *w, String *m);
+METHOD knh__Socket_new(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Socket_getInputStream(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Socket_getOutputStream(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Socket_close(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Socket_isClosed(Ctx *ctx, knh_sfp_t *sfp);
 void knh_InputStream_setEncoding(Ctx *ctx, InputStream *o, String *enc);
 void knh_OutputStream_setEncoding(Ctx *ctx, OutputStream *o, String *enc);
 /* ../src/api/stringapi.c */
@@ -456,7 +465,6 @@ int knh_NameSpace_loadScript(Ctx *ctx, NameSpace *ns, knh_bytes_t fpath, int isE
 void konoha_compile(Ctx *ctx, String *nsname, knh_bytes_t fpath);
 /* ../src/compiler/parser.c */
 Stmt *new_StmtINSTMT(Ctx *ctx, Token *tk);
-int knh_Token_isNEW(Ctx *ctx, Token *tk);
 void knh_Stmt_add_PEACH(Ctx *ctx, Stmt *o, knh_tokens_t *tc);
 /* ../src/compiler/perror.c */
 void knh_perrata(Ctx *ctx, knh_fileid_t fileid, int line, char *oldt, char *newt);
@@ -525,39 +533,34 @@ Term * knh_StmtMETHOD_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns);
 Term *knh_StmtFORMAT_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns);
 Term *knh_StmtCLASS_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns);
 int knh_Stmt_typingBLOCK(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, int isIteration);
-/* ../src/deps/driver_db.c */
+/* ../src/deps/dlopen.c */
+void *knh_dlopen(Ctx *ctx, const char* path, int mode);
+void *knh_dlsym(Ctx *ctx, void* hdr, const char* symbol);
+const char *knh_dlerror(Ctx *ctx);
+int knh_dlclose(Ctx *ctx, void* hdr);
+/* ../src/deps/file.c */
+int knh_isfile(Ctx *ctx, knh_bytes_t path);
+int knh_isdir(Ctx *ctx, knh_bytes_t path);
+char * knh_format_homepath(char *buf, size_t bufsiz);
+/* ../src/deps/io.c */
+knh_iodrv_t *konoha_getIODriver(Ctx *ctx, knh_bytes_t name);
+knh_iodrv_t *konoha_getDefaultIODriver();
+void  init_IO(Ctx *ctx);
+InputStream *new_InputStream__stdio(Ctx *ctx, FILE *fp, String *enc);
+OutputStream *new_OutputStream__stdio(Ctx *ctx, FILE *fp, String *enc);
+/* ../src/deps/regex.c */
+void knh_write_USING_REGEX(Ctx *ctx, OutputStream *w);
+knh_regex_drvapi_t *knh_System_getRegexDriver(Ctx *ctx, knh_bytes_t name);
+void  init_Regex(Ctx *ctx);
+/* ../src/deps/socket.c */
+knh_iodrv_t *konoha_getSocketDriver();
+void  init_SocketDriver(Ctx *ctx);
+/* ../src/deps/sqlite3.c */
 void knh_dbcurfree__NOP(knh_dbcur_t *dbcur);
 void knh_write_USING_SQLITE3(Ctx *ctx, OutputStream *w);
 knh_db_drvapi_t *knh_System_getDefaultDBDriver();
 knh_db_drvapi_t *knh_System_getDBDriver(Ctx *ctx, knh_bytes_t name);
 void  init_DB(Ctx *ctx);
-/* ../src/deps/driver_io.c */
-knh_iodrv_t *knh_System_getIODriver(Ctx *ctx, knh_bytes_t name);
-knh_iodrv_t knh_System_getDefaultIODriver();
-void  init_IO(Ctx *ctx);
-InputStream *new_InputStream__stdio(Ctx *ctx, FILE *fp, String *enc);
-OutputStream *new_OutputStream__stdio(Ctx *ctx, FILE *fp, String *enc);
-/* ../src/deps/driver_regex.c */
-void knh_write_USING_REGEX(Ctx *ctx, OutputStream *w);
-knh_regex_drvapi_t *knh_System_getRegexDriver(Ctx *ctx, knh_bytes_t name);
-void  init_Regex(Ctx *ctx);
-/* ../src/deps/posix.c */
-void *knh_dlopen(Ctx *ctx, const char* path, int mode);
-void *knh_dlsym(Ctx *ctx, void* hdr, const char* symbol);
-const char *knh_dlerror(Ctx *ctx);
-int knh_dlclose(Ctx *ctx, void* hdr);
-char * knh_format_homepath(char *buf, size_t bufsiz);
-int knh_isfile(Ctx *ctx, knh_bytes_t path);
-int knh_isdir(Ctx *ctx, knh_bytes_t path);
-int knh_isnewerfile(Ctx *ctx, char *path, char *path2);
-knh_uint_t knh_initseed();
-knh_uint64_t konoha_gettime();
-/* ../src/deps/tbmx1.c */
-void *knh_dlopen(Ctx *ctx, const char* path, int mode);
-void *knh_dlsym(Ctx *ctx, void* handle, const char* symbol);
-const char *knh_dlerror(Ctx *ctx);
-int knh_dlclose(Ctx *ctx, void* handle);
-char * knh_format_homepath(char *buf, size_t bufsiz);
 /* ../src/deps/thread.c */
 knh_thread_t knh_thread_self();
 int thread_create(knh_thread_t *thread, void *attr, void *(*frun)(void *), void * arg);
@@ -565,21 +568,12 @@ int knh_thread_key_create(knh_thread_key_t *key);
 int knh_thread_setspecific(knh_thread_key_t key, const void *data);
 void* knh_thread_getspecific(knh_thread_key_t key);
 int knh_thread_key_delete(knh_thread_key_t key);
-/* ../src/deps/win32.c */
-void *knh_dlopen(Ctx *ctx, const char* path, int mode);
-void *knh_dlsym(Ctx *ctx, void* handle, const char* symbol);
-const char *knh_dlerror(Ctx *ctx);
-int knh_dlclose(Ctx *ctx, void* handle);
-char * knh_format_homepath(char *buf, size_t bufsiz);
-int knh_isfile(Ctx *ctx, knh_bytes_t path);
-int knh_isdir(Ctx *ctx, knh_bytes_t path);
+/* ../src/deps/time.c */
 knh_uint_t knh_initseed();
 knh_uint64_t konoha_gettime();
 /* ../src/konoha.c */
 int main(int argc, char **argv);
 /* ../src/labs/b4.c */
-METHOD knh__Script_initfibo(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Script_fibo(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_changeChannel(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_hook(Ctx *ctx, knh_sfp_t *sfp);
 /* ../src/main/filesystem.c */
@@ -664,6 +658,7 @@ NameSpace *knh_System_loadPackage(Ctx *ctx, knh_bytes_t pkgname);
 NameSpace *knh_System_getNameSpace(Ctx *ctx, knh_bytes_t name);
 ClassSpec *konoha_getClassSpec(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn);
 /* ../src/main/systemtable.c */
+Ctx *new_Context(Ctx *parent);
 void knh_Context_traverse(Ctx *ctx, knh_Context_t *o, knh_ftraverse ftr);
 void konoha_traverse(Ctx* ctx, knh_ftraverse ftr);
 /* ../src/main/typesystem.c */
