@@ -71,7 +71,7 @@ extern "C" {
 #define TT_CATCH                        ((knh_token_t)28)
 #define TT_FINALLY                      ((knh_token_t)29)
 #define TT_THROW                        ((knh_token_t)30)
-#define TT_LOCAL                        ((knh_token_t)31)
+#define TT_REGISTER                     ((knh_token_t)31)
 #define TT_PRINT                        ((knh_token_t)32)
 #define TT_ASSERT                       ((knh_token_t)33)
 #define TT_BRACE                        ((knh_token_t)34)
@@ -331,7 +331,7 @@ extern "C" {
 #define STT_THROW                       ((knh_stmt_t)40)
 #define STT_ERR                         ((knh_stmt_t)41)
 #define STT_LET                         ((knh_stmt_t)42)
-#define STT_LOCAL                       ((knh_stmt_t)43)
+#define STT_REGISTER                    ((knh_stmt_t)43)
 #define STT_LETMULTI                    ((knh_stmt_t)44)
 #define STT_NEW                         ((knh_stmt_t)45)
 #define STT_MAPCAST                     ((knh_stmt_t)46)
@@ -633,9 +633,9 @@ extern "C" {
 #define LET_rvalue                      1
 
 /* ======================================================================== */
-/* [local] */
-#define StmtLOCAL_exprs_size(stmt)      (DP(stmt)->size - 0)
-#define StmtLOCAL_exprs(stmt,n)         DP(stmt)->terms[n-0]
+/* [register] */
+#define StmtREGISTER_exprs_size(stmt)   (DP(stmt)->size - 0)
+#define StmtREGISTER_exprs(stmt,n)      DP(stmt)->terms[n-0]
 
 /* ======================================================================== */
 /* [letmulti] */
