@@ -102,6 +102,7 @@ static char* StructName[] =  {
 	"StringUnit",
 	"InputStream",
 	"OutputStream",
+	"Socket",
 	"Connection",
 	"ResultSet",
 	"Exception",
@@ -467,6 +468,16 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_newClass)knh_OutputStream_newClass,
 		knh_OutputStream_getkey
 	},
+	{
+		"Socket", STRUCT_Socket, FLAG_Socket, sizeof(knh_Socket_struct),
+		(knh_fstruct_init)knh_Socket_init,
+		(knh_fstruct_copy)knh_Socket_copy, 
+		(knh_fstruct_traverse)knh_Socket_traverse,
+		(knh_fstruct_compareTo)knh_Socket_compareTo,
+		(knh_fstruct_hashCode)knh_Socket_hashCode,
+		(knh_fstruct_newClass)knh_Socket_newClass,
+		knh_Socket_getkey
+	},
 	{
 		"Connection", STRUCT_Connection, FLAG_Connection, sizeof(knh_Connection_struct),
 		(knh_fstruct_init)knh_Connection_init,
@@ -611,8 +622,8 @@ static knh_ClassData_t ClassData[] = {
 	{"konoha.Tuple2", CLASS_Tuple2, CFLAG_Tuple2, STRUCT_Tuple2, CLASS_Object, 0, 0, 0, knh_Tuple2_fdefault},
 	{"konoha.Range", CLASS_Range, CFLAG_Range, STRUCT_Range, CLASS_Object, 0, 0, 0, knh_Range_fdefault},
 	{"konoha.Array", CLASS_Array, CFLAG_Array, STRUCT_Array, CLASS_Object, 0, 31, 0, knh_Array_fdefault},
-	{"Int[]", CLASS_IArray, CFLAG_IArray, STRUCT_IArray, CLASS_Object, 0, 18, 0, knh_IArray_fdefault},
-	{"Float[]", CLASS_FArray, CFLAG_FArray, STRUCT_FArray, CLASS_Object, 0, 18, 0, knh_FArray_fdefault},
+	{"Int[]", CLASS_IArray, CFLAG_IArray, STRUCT_IArray, CLASS_Object, 0, 20, 0, knh_IArray_fdefault},
+	{"Float[]", CLASS_FArray, CFLAG_FArray, STRUCT_FArray, CLASS_Object, 0, 20, 0, knh_FArray_fdefault},
 	{"konoha.Iterator", CLASS_Iterator, CFLAG_Iterator, STRUCT_Iterator, CLASS_Object, 0, 1, 0, knh_Iterator_fdefault},
 	{"konoha.DictMap", CLASS_DictMap, CFLAG_DictMap, STRUCT_DictMap, CLASS_Object, 0, 12, 0, knh_DictMap_fdefault},
 	{"konoha.DictSet", CLASS_DictSet, CFLAG_DictSet, STRUCT_DictSet, CLASS_Object, 0, 13, 0, knh_DictSet_fdefault},
@@ -634,11 +645,12 @@ static knh_ClassData_t ClassData[] = {
 	{"konoha.StringUnit", CLASS_StringUnit, CFLAG_StringUnit, STRUCT_StringUnit, CLASS_Object, 0, 0, 0, knh_StringUnit_fdefault},
 	{"konoha.InputStream", CLASS_InputStream, CFLAG_InputStream, STRUCT_InputStream, CLASS_Object, 0, 6, 0, knh_InputStream_fdefault},
 	{"konoha.OutputStream", CLASS_OutputStream, CFLAG_OutputStream, STRUCT_OutputStream, CLASS_Object, 0, 16, 0, knh_OutputStream_fdefault},
+	{"konoha.Socket", CLASS_Socket, CFLAG_Socket, STRUCT_Socket, CLASS_Object, 0, 5, 0, knh_Socket_fdefault},
 	{"konoha.Connection", CLASS_Connection, CFLAG_Connection, STRUCT_Connection, CLASS_Object, 0, 4, 0, knh_Connection_fdefault},
 	{"konoha.ResultSet", CLASS_ResultSet, CFLAG_ResultSet, STRUCT_ResultSet, CLASS_Object, 0, 9, 0, knh_ResultSet_fdefault},
 	{"konoha.Exception", CLASS_Exception, CFLAG_Exception, STRUCT_Exception, CLASS_Object, 0, 9, 0, knh_Exception_fdefault},
 	{"konoha.ExceptionHandler", CLASS_ExceptionHandler, CFLAG_ExceptionHandler, STRUCT_ExceptionHandler, CLASS_Object, 0, 0, 0, knh_ExceptionHandler_fdefault},
-	{"konoha.Script", CLASS_Script, CFLAG_Script, STRUCT_Script, CLASS_Object, 0, 10, 0, knh_Script_fdefault},
+	{"konoha.Script", CLASS_Script, CFLAG_Script, STRUCT_Script, CLASS_Object, 0, 8, 0, knh_Script_fdefault},
 	{"konoha.NameSpace", CLASS_NameSpace, CFLAG_NameSpace, STRUCT_NameSpace, CLASS_Object, 0, 0, 0, knh_NameSpace_fdefault},
 	{"konoha.System", CLASS_System, CFLAG_System, STRUCT_System, CLASS_Object, 0, 15, 0, knh_System_fdefault},
 	{"konoha.Context", CLASS_Context, CFLAG_Context, STRUCT_Context, CLASS_Object, 0, 16, 0, knh_Context_fdefault},
@@ -653,6 +665,7 @@ static knh_GenericsData_t GenericsData[] = {
 	{"String[]", ACLASS_String, CLASS_Array, CLASS_String, CLASS_Nue},
 	{"String..", ICLASS_String, CLASS_Iterator, CLASS_String, CLASS_Nue},
 	{"Any1..", ICLASS_Any1, CLASS_Iterator, CLASS_Any1, CLASS_Nue},
+	{"Int..", ICLASS_Int, CLASS_Iterator, CLASS_Int, CLASS_Nue},
 	{"This..", ICLASS_This, CLASS_Iterator, CLASS_This, CLASS_Nue},
 	{NULL}
 };
@@ -728,7 +741,6 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"exec", FIELDN_exec},
 	{"exit", FIELDN_exit},
 	{"f", FIELDN_f},
-	{"fibo", FIELDN_fibo},
 	{"file", FIELDN_file},
 	{"float", FIELDN_float},
 	{"flush", FIELDN_flush},
@@ -743,12 +755,13 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"hasFile", FIELDN_hasFile},
 	{"hasMetaData", FIELDN_hasMetaData},
 	{"hook", FIELDN_hook},
+	{"host", FIELDN_host},
 	{"i", FIELDN_i},
 	{"in", FIELDN_in},
 	{"index", FIELDN_index},
 	{"indexOf", FIELDN_indexOf},
 	{"init", FIELDN_init},
-	{"initfibo", FIELDN_initfibo},
+	{"inputStream", FIELDN_inputStream},
 	{"insert", FIELDN_insert},
 	{"int", FIELDN_int},
 	{"invoke", FIELDN_invoke},
@@ -852,9 +865,11 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"opTo", FIELDN_opTo},
 	{"opXor", FIELDN_opXor},
 	{"out", FIELDN_out},
+	{"outputStream", FIELDN_outputStream},
 	{"p", FIELDN_p},
 	{"path", FIELDN_path},
 	{"pop", FIELDN_pop},
+	{"port", FIELDN_port},
 	{"print", FIELDN_print},
 	{"println", FIELDN_println},
 	{"proceed", FIELDN_proceed},
@@ -939,6 +954,7 @@ static knh_MethodFieldData_t MethodFieldData[] = {
 	{MFN_void_ArrayCmp, 1+ 0, TYPE_void, TYPE_ArrayCmp, FIELDN_f},
 	{MFN_void_OutputStream_Any, 2+ 0, TYPE_void, TYPE_OutputStream, FIELDN_w, TYPE_Any, FIELDN_m},
 	{MFN_iAny1, 0+ 0, NNITYPE_Any1},
+	{MFN_iInt, 0+ 0, NNITYPE_Int},
 	{MFN_nThis_nInt_nInt, 2+ 0, NNTYPE_This, NNTYPE_Int, FIELDN_x, NNTYPE_Int, FIELDN_y},
 	{MFN_nThis_nInt_nInt_nInt, 3+ 0, NNTYPE_This, NNTYPE_Int, FIELDN_x, NNTYPE_Int, FIELDN_y, NNTYPE_Int, FIELDN_z},
 	{MFN_Any1_nInt_nInt, 2+ 0, TYPE_Any1, NNTYPE_Int, FIELDN_x, NNTYPE_Int, FIELDN_y},
@@ -972,6 +988,7 @@ static knh_MethodFieldData_t MethodFieldData[] = {
 	{MFN_nInt_nString, 1+ 0, NNTYPE_Int, NNTYPE_String, FIELDN_k},
 	{MFN_void_nString_nInt, 2+ 0, TYPE_void, NNTYPE_String, FIELDN_k, NNTYPE_Int, FIELDN_v},
 	{MFN_void_String_, 1+ 0, TYPE_void, TYPE_String, FIELDN_v},
+	{MFN_Any2_Any1, 1+ 0, TYPE_Any2, TYPE_Any1, FIELDN_k},
 	{MFN_void_nAny1_Any2, 2+ 0, TYPE_void, NNTYPE_Any1, FIELDN_k, TYPE_Any2, FIELDN_v},
 	{MFN_nBoolean, 0+ 0, NNTYPE_Boolean},
 	{MFN_nBoolean_nInt, 1+ 0, NNTYPE_Boolean, NNTYPE_Int, FIELDN_v},
@@ -989,6 +1006,9 @@ static knh_MethodFieldData_t MethodFieldData[] = {
 	{MFN_InputStream_nString, 1+ 0, TYPE_InputStream, NNTYPE_String, FIELDN_u},
 	{MFN_OutputStream_nString_String, 2+ 0, TYPE_OutputStream, NNTYPE_String, FIELDN_u, TYPE_String, FIELDN_m},
 	{MFN_void_Any, 1+ 0, TYPE_void, TYPE_Any, FIELDN_v},
+	{MFN_nSocket_nString_nInt, 2+ 0, NNTYPE_Socket, NNTYPE_String, FIELDN_h, NNTYPE_Int, FIELDN_p},
+	{MFN_nInputStream, 0+ 0, NNTYPE_InputStream},
+	{MFN_nOutputStream, 0+ 0, NNTYPE_OutputStream},
 	{MFN_void_String, 1+ 0, TYPE_void, TYPE_String, FIELDN_e},
 	{MFN_nString_Any, 1+ 0, NNTYPE_String, TYPE_Any, FIELDN_v},
 	{MFN_nString_Any_, 1+ 0, NNTYPE_String, TYPE_Any, FIELDN_v},
@@ -998,9 +1018,7 @@ static knh_MethodFieldData_t MethodFieldData[] = {
 	{MFN_nString_Int_Int, 2+ 0, NNTYPE_String, TYPE_Int, FIELDN_o, TYPE_Int, FIELDN_l},
 	{MFN_nString, 0+ 0, NNTYPE_String},
 	{MFN_aString_Any, 1+ 0, ATYPE_String, TYPE_Any, FIELDN_d},
-	{MFN_nInputStream, 0+ 0, NNTYPE_InputStream},
 	{MFN_void_InputStream, 1+ 0, TYPE_void, TYPE_InputStream, FIELDN_i},
-	{MFN_nOutputStream, 0+ 0, NNTYPE_OutputStream},
 	{MFN_void_OutputStream, 1+ 0, TYPE_void, TYPE_OutputStream, FIELDN_o},
 	{MFN_void_Int, 1+ 0, TYPE_void, TYPE_Int, FIELDN_s},
 	{MFN_Any_nString, 1+ 0, TYPE_Any, NNTYPE_String, FIELDN_k},
@@ -1069,7 +1087,11 @@ static knh_MethodData_t MethodData[] = {
 	{knh__FArray_swap, 0, CLASS_FArray, METHODN_swap, 0, MFN_void_nInt_nInt, (void*)NULL},
 	{knh__FArray_shuffle, 0, CLASS_FArray, METHODN_shuffle, 0, MFN_void, (void*)NULL},
 	{knh_fmethod_movableText, 0, CLASS_Array, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_Array__k},
+	{knh_fmethod_movableText, 0, CLASS_IArray, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_IArray__k},
+	{knh_fmethod_movableText, 0, CLASS_FArray, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_FArray__k},
 	{knh__Array_opItr, 0, CLASS_Array, METHODN_opItr, 0, MFN_iAny1, (void*)NULL},
+	{knh__IArray_opItr, 0, CLASS_IArray, METHODN_opItr, 0, MFN_iInt, (void*)NULL},
+	{knh__FArray_opItr, 0, CLASS_FArray, METHODN_opItr, 0, MFN_iAny1, (void*)NULL},
 	{knh__Array_new__array2D, 0, CLASS_Array, METHODN_new__array2D, 0, MFN_nThis_nInt_nInt, (void*)NULL},
 	{knh__Array_new__array3D, 0, CLASS_Array, METHODN_new__array3D, 0, MFN_nThis_nInt_nInt_nInt, (void*)NULL},
 	{knh__Array_get2D, 0, CLASS_Array, METHODN_get2D, 0, MFN_Any1_nInt_nInt, (void*)NULL},
@@ -1132,7 +1154,7 @@ static knh_MethodData_t MethodData[] = {
 	{knh_fmethod_movableText, 0, CLASS_DictSet, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_DictSet__k},
 	{knh_fmethod_movableText, 0, CLASS_DictSet, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_DictSet__dump},
 	{knh__HashMap_new, 0, CLASS_HashMap, METHODN_new, 0, MFN_nThis_Int, (void*)NULL},
-	{knh__HashMap_get, 0, CLASS_HashMap, METHODN_get, 0, MFN_void_Any1, (void*)NULL},
+	{knh__HashMap_get, 0, CLASS_HashMap, METHODN_get, 0, MFN_Any2_Any1, (void*)NULL},
 	{knh__HashMap_opHas, 0, CLASS_HashMap, METHODN_opHas, 0, MFN_nBoolean_Any1, (void*)NULL},
 	{knh__HashMap_remove, 0, CLASS_HashMap, METHODN_remove, 0, MFN_void_Any1, (void*)NULL},
 	{knh__HashMap_set, 0, CLASS_HashMap, METHODN_set, 0, MFN_void_nAny1_Any2, (void*)NULL},
@@ -1229,6 +1251,11 @@ static knh_MethodData_t MethodData[] = {
 	{knh__OutputStream_println, 0, CLASS_OutputStream, METHODN_println, 0, MFN_void_Any, (void*)NULL},
 	{knh__OutputStream_opLshift, KNH_FLAG_MF_VARARGS, CLASS_OutputStream, METHODN_opLshift, 0, MFN_void_Any_, (void*)NULL},
 	{knh_fmethod_movableText, 0, CLASS_OutputStream, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_OutputStream__k},
+	{knh__Socket_new, 0, CLASS_Socket, METHODN_new, 0, MFN_nSocket_nString_nInt, (void*)NULL},
+	{knh__Socket_getInputStream, 0, CLASS_Socket, METHODN_getInputStream, 0, MFN_nInputStream, (void*)NULL},
+	{knh__Socket_getOutputStream, 0, CLASS_Socket, METHODN_getOutputStream, 0, MFN_nOutputStream, (void*)NULL},
+	{knh__Socket_close, 0, CLASS_Socket, METHODN_close, 0, MFN_void, (void*)NULL},
+	{knh__Socket_isClosed, 0, CLASS_Socket, METHODN_isClosed, 0, MFN_nBoolean, (void*)NULL},
 	{knh__InputStream_setEncoding, 0, CLASS_InputStream, METHODN_setEncoding, 0, MFN_void_String, (void*)NULL},
 	{knh__OutputStream_setEncoding, 0, CLASS_OutputStream, METHODN_setEncoding, 0, MFN_void_String, (void*)NULL},
 	{knh__String_equals, KNH_FLAG_MF_CONST, CLASS_String, METHODN_equals, 0, MFN_nBoolean_nString, (void*)NULL},
@@ -1318,8 +1345,6 @@ static knh_MethodData_t MethodData[] = {
 	{knh_fmethod_movableText, 0, CLASS_Token, METHODN__s, 0, MFN_void_OutputStream_Any, (void*)knh_Token__s},
 	{knh_fmethod_movableText, 0, CLASS_Token, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_Token__k},
 	{knh_fmethod_movableText, 0, CLASS_Token, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_Token__dump},
-	{knh__Script_initfibo, 0, CLASS_Script, METHODN_initfibo, 0, MFN_nInt, (void*)NULL},
-	{knh__Script_fibo, 0, CLASS_Script, METHODN_fibo, 0, MFN_nInt_nInt, (void*)NULL},
 	{knh__Script_changeChannel, 0, CLASS_Script, METHODN_changeChannel, 0, MFN_void_nInt, (void*)NULL},
 	{knh__Script_hook, 0, CLASS_Script, METHODN_hook, 0, MFN_void_nString, (void*)NULL},
 	{knh__Script_eval, 0, CLASS_Script, METHODN_eval, 0, MFN_void_String_String_Int, (void*)NULL},
@@ -1392,6 +1417,8 @@ static knh_MethodData_t MethodData[] = {
 static knh_MapperData_t MapperData[] = {
 	{knh_Array_Iterator, KNH_FLAG_MMF_TOTAL, CLASS_Array, CLASS_Iterator},
 	{knh_Iterator_Array, KNH_FLAG_MMF_TOTAL, CLASS_Iterator, CLASS_Array},
+	{knh_IArray_Iterator, KNH_FLAG_MMF_TOTAL, CLASS_IArray, CLASS_Iterator},
+	{knh_FArray_Iterator, KNH_FLAG_MMF_TOTAL, CLASS_FArray, CLASS_Iterator},
 	{knh_Bytes_String, KNH_FLAG_MMF_CONST|KNH_FLAG_MMF_FINAL|KNH_FLAG_MMF_TOTAL, CLASS_Bytes, CLASS_String},
 	{knh_String_Bytes, KNH_FLAG_MMF_CONST|KNH_FLAG_MMF_FINAL|KNH_FLAG_MMF_TOTAL, CLASS_String, CLASS_Bytes},
 	{knh_DictMap_Iterator, KNH_FLAG_MMF_TOTAL, CLASS_DictMap, CLASS_Iterator},
@@ -1418,9 +1445,10 @@ static knh_MapperData_t MapperData[] = {
 typedef void (*knh_finit_)(Ctx *);
 
 static knh_finit_ InitFuncData[] = {
-	init_DB,
 	init_IO,
 	init_Regex,
+	init_SocketDriver,
+	init_DB,
 	NULL
 };
 
