@@ -52,7 +52,7 @@ extern "C" {
 
 #define METHOD             void  KNH_CC_FASTCALL
 #define MAPPER             METHOD
-#define ITRNEXT            METHOD
+#define ITRNEXT            int   KNH_CC_FASTCALL
 
 #ifdef KNH_USING_THREAD
 #define KNH_MT_VOLATILE           volatile
@@ -812,14 +812,15 @@ typedef struct {
 
 typedef knh_intptr_t knh_io_t;
 
-typedef knh_io_t (*f_io_open)(Ctx *ctx, struct knh_InputStream_t *in, struct knh_OutputStream_t *out, knh_bytes_t urn, char *mode);
+typedef knh_io_t (*f_io_open)(Ctx *ctx, knh_bytes_t urn, char *mode);
 typedef knh_intptr_t (*f_io_read)(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz);
 typedef knh_intptr_t (*f_io_write)(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz);
 typedef void   (*f_io_close)(Ctx *ctx, knh_io_t fd);
 
 typedef struct {
-	int type; char *name;
-	size_t bufsiz;
+	int type;
+	char *name;
+	size_t bufsiz;  /* knh_io_t == FILE* if bufsiz == 0 */
 	f_io_open    fopen;
 	f_io_read    fread;
 	f_io_write   fwrite;
