@@ -43,23 +43,19 @@ extern "C" {
 #define _knh_Bytes_value(o)     (o)->buf
 #define _knh_Bytes_last(o)      ((o)->buf + (o)->size)
 
-#ifndef KNH_PAGESIZE
-#define KNH_PAGESIZE   4096
-#endif
-
 /* ======================================================================== */
 /* [barray] */
 
 
 size_t knh_bytes_newsize(size_t s)
 {
-	if(s <= 256) return 256;
-	if(s <= KNH_PAGESIZE) {
+	if(s <= KONOHA_SMALLPAGESIZE) return KONOHA_SMALLPAGESIZE;
+	if(s <= KONOHA_PAGESIZE) {
 		if(s <= 1024) return 1024;
-		return KNH_PAGESIZE;
+		return KONOHA_PAGESIZE;
 	}
-	if((s % KNH_PAGESIZE) == 0) return s;
-	return ((s / KNH_PAGESIZE)+1) * KNH_PAGESIZE;
+	if((s % KONOHA_PAGESIZE) == 0) return s;
+	return ((s / KONOHA_PAGESIZE)+1) * KONOHA_PAGESIZE;
 }
 
 /* ------------------------------------------------------------------------ */
