@@ -234,14 +234,14 @@ char *knh_lookup_includeScript(Ctx *ctx, knh_bytes_t path, char *buf, size_t buf
 	char *filename = (char*)path.buf + loc + 1;
 
 #ifdef KNH_PREFIX
-	knh_snprintf(buf, bufsiz, "%s/lib/konoha/%s", KNH_PREFIX, filename);
+	knh_snprintf(buf, bufsiz, "%s/lib/konoha/include/%s", KNH_PREFIX, filename);
 #else
 	knh_snprintf(buf, bufsiz, "%s/include/%s", knh_String_tochar(DP(ctx->sys)->homeDir), filename);
 #endif
 	if(knh_isfile(ctx, B(buf))) return buf;
 	char *p = knh_getenv("HOME");
 	if(p != NULL) {
-		knh_snprintf(buf, bufsiz, "%s/.konoha/%s", p, filename);
+		knh_snprintf(buf, bufsiz, "%s/.konoha/include/%s", p, filename);
 		if(knh_isfile(ctx, B(buf))) return buf;
 	}
 	return NULL;
@@ -512,21 +512,22 @@ int knh_Stmt_eval(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, int isEval)
 	}
 	KNH_LPUSH(ctx, stmt);
 	KNH_ASM_METHOD(ctx, abr, mtd, NULL, stmt, 0 /* isIteration */);
-
-	if(knh_Method_isAbstract(mtd)) {
+	if(knh_Method_isAbstract(mtd) || SP(stmt)->stt == STT_ERR) {
 		KNH_LOCALBACK(ctx, lsfp);
 		return 0;
 	}
 
+	int isVOID = knh_Stmt_isVOID(stmt);
 	if(isEval) {
 		ExceptionHandler *hdr = new_ExceptionHandler(ctx);
 		KNH_MOV(ctx, lsfp[0].o, hdr);
 		KNH_TRY(ctx, L_CATCH, lsfp, 0);
 		{
+			KNH_MOV(ctx, lsfp[1].o, DP(mtd)->code); // TO AVOID RCGC
 			KNH_MOV(ctx, lsfp[3].o, scr);
 			KNH_SCALL(ctx, lsfp, 2, mtd, 0/*args*/);
-			if(isExpr && !knh_Stmt_isVOID(stmt)) {
-				//DBG2_P("returning %s %lld", CTXCLASSN(knh_Object_cid(lsfp[1].o)), lsfp[1].ivalue);
+			if(isExpr && !isVOID) {
+				//DBG_P("returning %s %lld", CLASSN(knh_Object_cid(lsfp[2].o)), lsfp[2].ivalue);
 				((Context*)ctx)->esp = lsfp+1;
 				knh_esp1_format(ctx, mt, KNH_STDOUT, KNH_NULL);
 				knh_write_EOL(ctx, KNH_STDOUT);
@@ -726,8 +727,10 @@ void knh_Asm_openlib(Ctx *ctx, Asm *abr, knh_bytes_t fpath)
 {
 	knh_cwb_t cwb = new_cwb(ctx);
 	knh_index_t idx = knh_bytes_rindex(fpath, '.');
-	if(idx > 0) fpath.len = idx;
+	if(idx > 0) fpath = knh_bytes_first(fpath, idx);
 	knh_Bytes_write(ctx, cwb.ba, fpath);
+	knh_Bytes_putc(ctx, cwb.ba, '_');
+	knh_Bytes_write(ctx, cwb.ba, STEXT(KONOHA_PLATFORM));
 	knh_Bytes_write(ctx, cwb.ba, STEXT(KONOHA_OS_DLLEXT));
 	knh_Bytes_putc(ctx, cwb.ba, 0);
 
