@@ -595,17 +595,6 @@ METHOD knh__Method_getName(Ctx *ctx, knh_sfp_t *sfp)
 	KNH_RETURN(ctx, sfp, rv);
 }
 
-static
-METHOD knh__Method_getURN(Ctx *ctx, knh_sfp_t *sfp)
-{
-	/* method String! Method.getURN()  */
-	Object *rv = (Object*)knh_Method_getURN(
-		ctx,
-		(knh_Method_t*)sfp[0].o
-	);
-	KNH_RETURN(ctx, sfp, rv);
-}
-
 static
 METHOD knh__OutputStream_flush(Ctx *ctx, knh_sfp_t *sfp)
 {
