@@ -143,10 +143,6 @@ void knh_sfp_typecheck(Ctx *ctx, knh_sfp_t *sfp, Method *mtd, knh_code_t *pc)
 	}
 }
 
-/* ======================================================================== */
-/* [movabletext] */
-
-
 /* ======================================================================== */
 /* [macros] */
 
@@ -182,6 +178,13 @@ KNHAPI(void) knh_throw_TODO(Ctx *ctx, char *file, int line, char *func)
 	knh_throwException(ctx, new_Exception__b(ctx, STEXT("UnsupportedOperation!!")), KNH_SAFEFILE(file), line);
 }
 
+/* ------------------------------------------------------------------------ */
+
+KNHAPI(void) knh_throw_bugstop(Ctx *ctx, char *file, int line, char *func)
+{
+	knh_throwException(ctx, new_Exception__b(ctx, STEXT("ReportedBugStop!!")), KNH_SAFEFILE(file), line);
+}
+
 /* ======================================================================== */
 /* [throw] */
 
